==> gtk-3.96.0.tar.xz: gtk-3.96.0/gtk/gtkpango.h <==
/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __GTK_PANGO_H__
#define __GTK_PANGO_H__


#include <pango/pangocairo.h>
#include <atk/atk.h>

G_BEGIN_DECLS

AtkAttributeSet *_gtk_pango_get_default_attributes (AtkAttributeSet *attributes,
                                                    PangoLayout     *layout);

AtkAttributeSet *_gtk_pango_get_run_attributes     (AtkAttributeSet *attributes,
                                                    PangoLayout     *layout,
                                                    gint             offset,
                                                    gint            *start_offset,
                                                    gint            *end_offset);

gchar *_gtk_pango_get_text_before (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);
gchar *_gtk_pango_get_text_at     (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);
gchar *_gtk_pango_get_text_after  (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);

PangoAttrList *_gtk_pango_attr_list_merge (PangoAttrList *into,
                                           PangoAttrList *from);

G_END_DECLS

#endif /* __GTK_PANGO_H__ */

==> gtk-3.98.3.tar.xz: gtk-3.98.3/gtk/gtkpango.h <==
/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __GTK_PANGO_H__
#define __GTK_PANGO_H__


#include <pango/pangocairo.h>
#include <atk/atk.h>
#include  "gtkbuildable.h"

G_BEGIN_DECLS

AtkAttributeSet *_gtk_pango_get_default_attributes (AtkAttributeSet *attributes,
                                                    PangoLayout     *layout);

AtkAttributeSet *_gtk_pango_get_run_attributes     (AtkAttributeSet *attributes,
                                                    PangoLayout     *layout,
                                                    gint             offset,
                                                    gint            *start_offset,
                                                    gint            *end_offset);

gchar *_gtk_pango_get_text_before (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);
gchar *_gtk_pango_get_text_at     (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);
gchar *_gtk_pango_get_text_after  (PangoLayout     *layout,
                                   AtkTextBoundary  boundary_type,
                                   gint             offset,
                                   gint            *start_offset,
                                   gint            *end_offset);

PangoAttrList *_gtk_pango_attr_list_merge (PangoAttrList *into,
                                           PangoAttrList *from);

gboolean gtk_buildable_attribute_tag_start (GtkBuildable       *buildable,
                                            GtkBuilder         *builder,
                                            GObject            *child,
                                            const gchar        *tagname,
                                            GtkBuildableParser *parser,
                                            gpointer           *data);

typedef struct {
  GtkBuilder    *builder;
  GObject       *object;
  PangoAttrList *attrs;
} GtkPangoAttributeParserData;

void
gtk_pango_attribute_start_element (GtkBuildableParseContext  *context,
                                   const char                *element_name,
                                   const char               **names,
                                   const char               **values,
                                   gpointer                   user_data,
                                   GError                   **error);

G_END_DECLS

#endif /* __GTK_PANGO_H__ */
